@@ -421,15 +421,16 @@ class AirbyteConnectionMetadata(
                 else stream["stream"]["jsonSchema"]
             )
             normalization_tables: Dict[str, AirbyteTableMetadata] = {}
+            schema_props = schema.get("properties", schema.get("items", {}).get("properties", {}))
             if self.has_basic_normalization and return_normalization_tables:
-                for k, v in schema["properties"].items():
+                for k, v in schema_props.items():
                     for normalization_table_name, meta in _get_normalization_tables_for_schema(
                         k, v, f"{name}_"
                     ).items():
                         prefixed_norm_table_name = f"{self.stream_prefix}{normalization_table_name}"
                         normalization_tables[prefixed_norm_table_name] = meta
             tables[prefixed_name] = AirbyteTableMetadata(
-                schema=generate_table_schema(schema["properties"]),
+                schema=generate_table_schema(schema_props),
                 normalization_tables=normalization_tables,
             )
 
@@ -722,10 +723,10 @@ def load_assets_from_airbyte_instance(
         connection_to_group_fn (Optional[Callable[[str], Optional[str]]]): Function which returns an asset
             group name for a given Airbyte connection name. If None, no groups will be created. Defaults
             to a basic sanitization function.
-        io_manager_key (Optional[str]): The IO manager key to use for all assets. Defaults to "io_manager".
+        io_manager_key (Optional[str]): The I/O manager key to use for all assets. Defaults to "io_manager".
             Use this if all assets should be loaded from the same source, otherwise use connection_to_io_manager_key_fn.
         connection_to_io_manager_key_fn (Optional[Callable[[str], Optional[str]]]): Function which returns an
-            IO manager key for a given Airbyte connection name. When other ops are downstream of the loaded assets,
+            I/O manager key for a given Airbyte connection name. When other ops are downstream of the loaded assets,
             the IOManager specified determines how the inputs to those ops are loaded. Defaults to "io_manager".
         connection_filter (Optional[Callable[[AirbyteConnectionMetadata], bool]]): Optional function which takes
             in connection metadata and returns False if the connection should be excluded from the output assets.
@@ -823,10 +824,10 @@ def load_assets_from_airbyte_project(
         connection_to_group_fn (Optional[Callable[[str], Optional[str]]]): Function which returns an asset
             group name for a given Airbyte connection name. If None, no groups will be created. Defaults
             to a basic sanitization function.
-        io_manager_key (Optional[str]): The IO manager key to use for all assets. Defaults to "io_manager".
+        io_manager_key (Optional[str]): The I/O manager key to use for all assets. Defaults to "io_manager".
             Use this if all assets should be loaded from the same source, otherwise use connection_to_io_manager_key_fn.
         connection_to_io_manager_key_fn (Optional[Callable[[str], Optional[str]]]): Function which returns an
-            IO manager key for a given Airbyte connection name. When other ops are downstream of the loaded assets,
+            I/O manager key for a given Airbyte connection name. When other ops are downstream of the loaded assets,
             the IOManager specified determines how the inputs to those ops are loaded. Defaults to "io_manager".
         connection_filter (Optional[Callable[[AirbyteConnectionMetadata], bool]]): Optional function which
             takes in connection metadata and returns False if the connection should be excluded from the output assets.
